'use strict';

var esbuild = require('esbuild');
var consola = require('consola');
var chalk = require('chalk');
var getViteConfig = require('./get-vite-config-0a8dd17a.js');
var vite = require('vite');
require('path');
require('fs-extra');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var consola__default = /*#__PURE__*/_interopDefaultLegacy(consola);
var chalk__default = /*#__PURE__*/_interopDefaultLegacy(chalk);

async function build(api) {
  const serverConfig = getViteConfig.getViteConfig(api, true);
  await Promise.all([
    vite.build(serverConfig),
    vite.build(getViteConfig.getViteConfig(api, false))
  ]);
}
async function buildStandalone(api) {
  const inputFile = api.resolveDotReam("meta/server-context.js");
  const outFile = api.resolveDotReam("meta/server-context-bundle.js");
  const {warnings} = await esbuild.build({
    entryPoints: [inputFile],
    outfile: outFile,
    bundle: true,
    format: "cjs",
    platform: "node",
    minify: !process.env.DEBUG,
    logLevel: "error"
  });
  for (const warning of warnings) {
    if (!warning.text.includes('Indirect calls to "require" will not be bundled')) {
      consola__default['default'].warn(chalk__default['default'].bold(warning.text));
      if (warning.location) {
        console.log(`${warning.location.file}:${warning.location.line}:${warning.location.column}`);
        console.log(warning.location.lineText);
      }
    }
  }
}

exports.build = build;
exports.buildStandalone = buildStandalone;
