import { build as build$2 } from 'esbuild';
import consola from 'consola';
import chalk from 'chalk';
import { getViteConfig } from './get-vite-config-cc12cca2.mjs';
import { build as build$1 } from 'vite';
import 'path';
import 'fs-extra';

async function build(api) {
  const serverConfig = getViteConfig(api, true);
  await Promise.all([
    build$1(serverConfig),
    build$1(getViteConfig(api, false))
  ]);
}
async function buildStandalone(api) {
  const inputFile = api.resolveDotReam("meta/server-context.js");
  const outFile = api.resolveDotReam("meta/server-context-bundle.js");
  const {warnings} = await build$2({
    entryPoints: [inputFile],
    outfile: outFile,
    bundle: true,
    format: "cjs",
    platform: "node",
    minify: !process.env.DEBUG,
    logLevel: "error"
  });
  for (const warning of warnings) {
    if (!warning.text.includes('Indirect calls to "require" will not be bundled')) {
      consola.warn(chalk.bold(warning.text));
      if (warning.location) {
        console.log(`${warning.location.file}:${warning.location.line}:${warning.location.column}`);
        console.log(warning.location.lineText);
      }
    }
  }
}

export { build, buildStandalone };
